﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Reflection;
using Foundation;
using Syncfusion.SfChart.iOS;
using UIKit;

namespace Chart_GettingStarted
{
	public partial class ViewController : UIViewController
	{
		protected ViewController(IntPtr handle) : base(handle)
		{
			// Note: this .ctor should not contain any initialization logic.
		}
        SFChart chart;

		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			//Initialize the Chart with required frame. This frame can be any rectangle, which bounds inside the view.
			chart = new SFChart();
			chart.Frame = this.View.Frame;

			//Adding Primary Axis for the Chart.
            SFDateTimeAxis primaryAxis = new SFDateTimeAxis();
			chart.PrimaryAxis = primaryAxis;

			//Adding Secondary Axis for the Chart.
			SFNumericalAxis secondaryAxis = new SFNumericalAxis();
			chart.SecondaryAxis = secondaryAxis;
            secondaryAxis.Maximum = new NSNumber(150);

			//Initializing view model
			ViewModel model = new ViewModel();
                
            SFColumnSeries series1 = new SFColumnSeries();
            series1.ItemsSource = model.Data2;
            series1.XBindingPath = "Date";
            series1.YBindingPath = "Volume";

            SFCandleSeries series2 = new SFCandleSeries();
            series2.ItemsSource = model.Data2;
            series2.XBindingPath = "Date";
            series2.High = "High";
            series2.Low = "Low";
            series2.Open = "Open";
            series2.Close = "Close";

            chart.Series.Add(series1);
            chart.Series.Add(series2);
                    
            this.View.AddSubview(chart);
		}


        public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
			// Release any cached data, images, etc that aren't in use.
		}
	}

    public class ViewModel
    {
        public ObservableCollection<Model> Data1 { get; set; }
        public ObservableCollection<Model> Data2 { get; set; }

        public ViewModel()
        {

            Random random = new Random();

            Data2 = new ObservableCollection<Model>(){
                
                new Model(new DateTime(2018, 10, 2),  50, 20, 30, 40, 20),
                new Model(new DateTime(2018, 10, 3),  60, 20, 30, 40, 30),
                new Model(new DateTime(2018, 10, 4),  40, 20, 30, 80, 40),
                new Model(new DateTime(2018, 10, 5),  70, 34, 34, 40, 20),
                new Model(new DateTime(2018, 10, 6),  60, 20, 30, 50, 15),
                new Model(new DateTime(2018, 10, 7),  50, 20, 30, 40, 35),
                new Model(new DateTime(2018, 10, 8),  60, 20, 56, 40, 26),
                new Model(new DateTime(2018, 10, 9),  40, 20, 30, 40, 34), 
                new Model(new DateTime(2018, 10, 10), 70, 20, 30, 90, 56),
                new Model(new DateTime(2018, 10, 11), 30, 12, 67, 40, 23),
                new Model(new DateTime(2018, 10, 12), 50, 20, 30, 40, 12),
                new Model(new DateTime(2018, 10, 13), 60, 56, 30, 70, 23),
            };                                       
        }
    }

    public class Model
    {
        public DateTime Date { get; set; }
        public string XValue { get; set; }
        public double High { get; set; }
        public double Low { get; set; }
        public double Open { get; set; }
        public double Close { get; set; }
        public double Volume { get; set; }

        public Model(string xValue, double high, double low, double open, double close)
        {
            XValue = xValue;
            High = high;
            Low = low;
            Close = close;
            Open = open;
        }

        public Model(DateTime xValue, double high, double low, double open, double close, double volume)
        {
            Date = xValue;
            High = high;
            Low = low;
            Close = close;
            Open = open;
            Volume = volume;
        }
    }
}